"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.bootstrapColors = void 0;

var _colorManipulator = require("@material-ui/core/styles/colorManipulator");

var _makeStyles = _interopRequireDefault(require("@material-ui/core/styles/makeStyles"));

var _react = _interopRequireDefault(require("react"));

var _Typography = _interopRequireDefault(require("./Typography"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Emulates the bootstrap alert boxes
 */
const useStyles = (0, _makeStyles.default)(theme => {
  const bootstrapColors = {
    primary: {
      backgroundColor: (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(theme.palette.primary.light, 0.7), 0.8),
      borderColor: (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(theme.palette.primary.light, 0.5), 0.8)
    },
    secondary: {
      backgroundColor: (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(theme.palette.secondary.light, 0.7), 0.8),
      borderColor: (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(theme.palette.secondary.light, 0.5), 0.8)
    },
    success: {
      backgroundColor: (0, _colorManipulator.fade)("#d4edda", 0.8),
      borderColor: (0, _colorManipulator.fade)("#c3e6cb", 0.8)
    },
    danger: {
      backgroundColor: (0, _colorManipulator.fade)("#f8d7da", 0.8),
      borderColor: (0, _colorManipulator.fade)("#f5c6cb", 0.8)
    },
    warning: {
      backgroundColor: (0, _colorManipulator.fade)("#fff3cd", 0.8),
      borderColor: (0, _colorManipulator.fade)("#ffeeba", 0.8)
    },
    info: {
      backgroundColor: (0, _colorManipulator.fade)("#d1ecf1", 0.8),
      borderColor: (0, _colorManipulator.fade)("#bee5eb", 0.8)
    },
    light: {
      backgroundColor: theme.palette.background.paper,
      borderColor: (0, _colorManipulator.fade)(theme.palette.text.secondary, 0.1)
    },
    dark: {
      backgroundColor: (0, _colorManipulator.fade)(theme.palette.text.primary, 0.25),
      borderColor: (0, _colorManipulator.fade)(theme.palette.text.primary, 0.2)
    }
  };

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "danger" : x.color];
  }

  return {
    root: {
      backgroundColor: x => getColor(x).backgroundColor,
      borderColor: x => getColor(x).borderColor,
      position: "relative",
      border: "1px solid",
      padding: ".75rem 1.25rem",
      borderRadius: ".25rem",
      width: "100%"
    }
  };
});
const bootstrapColors = ["primary", "secondary", "success", "danger", "warning", "info", "light", "dark"];
exports.bootstrapColors = bootstrapColors;

function Alert(props) {
  const classes = useStyles(props);
  return _react.default.createElement("div", {
    className: classes.root
  }, _react.default.createElement(_Typography.default, {
    color: props.color
  }, props.children));
}

function Heading(props) {
  return _react.default.createElement(_Typography.default, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.children);
}

Alert.Heading = Heading;
var _default = Alert;
exports.default = _default;